(stickler _ & args)protobuf3 -> EDN schema, for use with stickler.codec.
:dirs /proto ... A sequence of absolute directories to process into a protobuf schema. The EDN is pretty-printed to stdout
:include a.b/C ... An optional sequence of fully qualified type names. Output will be restricted to those types and their transitive dependencies.
protobuf3 -> EDN schema, for use with stickler.codec.
:dirs /proto ...
A sequence of absolute directories to process into a protobuf schema.
The EDN is pretty-printed to stdout
:include a.b/C ...
An optional sequence of fully qualified type names. Output
will be restricted to those types and their transitive dependencies.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |